@@ -27,7 +27,7 @@
 import os
 import gtk
 
-share_files_dir= os.path.join("/usr","share/","nanny/client/gnome/admin/")
+share_files_dir= os.path.join("/usr/local","share/","nanny/client/gnome/admin/")
 ui_files_dir= os.path.join(share_files_dir,"ui/")
 icons_files_dir= os.path.join(share_files_dir,"icons/")
 
